function [c,t,y]=FourierSeries(K,type,alfa,T,tstep,N)
%function [c,t,y]=FourierSeries(K,type,alfa,T,tstep,N)
%c: fourier series values among -K and K 
%   periodic train of pulses
%   with normalized duration alfa (0<alfa<=1)
%
%type: 1 rectangular, 2 triangular, 3 cosine,4 square cosine
%
%T: period of the reconstructed y signal 
%N: y consits of 2*N+1 periods
%t: time axes which has tstep resolution

k=-K:K;
t=-N*T:tstep:N*T;
switch type
    case 1
        c=alfa*sinc(k*alfa);
    case 2
        c=(alfa/2)*(sinc(k*alfa/2)).^2;
    case 3
        c(abs(k)~=1/(2*alfa))=2*alfa*cos(alfa*k(abs(k)~=1/(2*alfa))*pi)./(1-(2*alfa*k(abs(k)~=1/(2*alfa))).^2)/pi;
        c(abs(k)==1/(2*alfa))=alfa/2;
    case 4
        c(abs(k)~=1/alfa&k~=0)=sin(alfa*k(abs(k)~=1/alfa&k~=0)*pi)./(2*k(abs(k)~=1/alfa&k~=0)*pi.*(1-(alfa*k(abs(k)~=1/alfa&k~=0)).^2)); 
        c(abs(k)==1/alfa)=alfa/4;
        c(k==0)=alfa/2;
end
yi=zeros(length(k),length(t));
for i=1:length(k); yi(i,:)=c(i)*cos(2*pi*k(i)*t/T); end
y=sum(yi);